gs_quant.timeseries.algebra.log — gs_quant 0.1 documentation

# gs_quant.timeseries.algebra.log

`log`(x)

  Natural logarithm of series

  Parameters

    x (`Series`) – timeseries

  Return type

    `Series`

  Returns

    series with exponential of each element

  Usage

  For each element in the series, \(X_t\), return the natural logarithm \(ln\) of \(X_t\) The natural logarithm is the logarithm in base \(e\).

  \(R_t = log(X_t)\)

  This function is the inverse of the exponential function.

  More information on logarithms

  Examples

  Take natural logarithm of 3

      >>> log(3)

  See also

  `exp()`